Usage
=====

TODO

Here are the command line options for `evariste` and `evs`.

.. argparse::
    :module: evariste.evs.compile.options
    :func: commandline_parser
    :prog: evariste

TODO Some command line arguments can be set in setup file

#.. argparse::
    :module: evariste.evs.__main__
    :func: commandline_parser
    :prog: evs

TODO Some command line arguments can be set in setup file
